==> library1.4.1.tar.bz2: library/film-nal_on_frm.php <==
<?php
  ///////////////////////////////////////////////////
  //Вернуть книгу
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
  require_once "utils/chlang_osn.php";

  $title = $TEXT['book-nal-tit2'];
  $button = $TEXT['book-nal'];
  $action = "film-nal_on.php";

  require_once "config_a.php";
  require_once "utils/functions.php";
  require_once "utils/top_film.php";

  if($result2['administrator'] == 0) {puterror2($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom_film.php"; exit();}

  if(empty($_GET['film_id'])) {puterror2($result2['skin'],$TEXT['error-film5']); require_once "utils/bottom_film.php"; exit();}
  if(strlen($_GET['film_id'])>20) {puterror2($result2['skin'],$TEXT['error-film6']); require_once "utils/bottom_film.php"; exit();}
  $_GET['film_id'] = rep($_GET['film_id']);

?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center" >
<tr><td class="bold_it"><?php echo $TEXT['menu-btn26-title']; ?></td><td>
    <select name="obr_id">
    <?php
        $query10 = "SELECT * FROM `tbl_obraschenie` ORDER BY kachestvo ";
          $result10 = mysqli_query($dbcnx,$query10);
            if (!$result10) {puterror2($result2['skin'],$TEXT['error-tbl18']); require_once "utils/bottom_film.php"; exit();}
              while($result_obr = mysqli_fetch_array($result10))
                {
                 $chk_obr = "<option value=".$result_obr['obr_id'].">".$result_obr['kachestvo']."";
                 echo $chk_obr;
                }
    ?>
    </select></td></tr>
<tr><td></td><td><input class="button2" type=submit value='<?php echo $button; ?>' />
<input type=hidden name=film_id value='<?php echo $_GET['film_id']; ?>' />
</td></tr>
</table>
</form>
<?php
  require_once "utils/bottom_film.php";
?>

==> library1.19.1.tar.bz2: library/film-nal_on_frm.php <==
<?php
  ///////////////////////////////////////////////////
  //Вернуть книгу
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
  require_once "utils/chlang_osn.php";

  $title = $TEXT['book-nal-tit2'];
  $button = $TEXT['book-nal'];
  $action = "film-nal_on.php";

  require_once "config_a.php";
  require_once "utils/functions.php";
  require_once "utils/top_film.php";

  if($result2['administrator'] == 0) {puterror2($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom_film.php"; exit();}

  if(empty($_GET['film_id'])) {puterror2($result2['skin'],$TEXT['error-film5']); require_once "utils/bottom_film.php"; exit();}
  if(strlen($_GET['film_id'])>20) {puterror2($result2['skin'],$TEXT['error-film6']); require_once "utils/bottom_film.php"; exit();}
  $_GET['film_id'] = rep($_GET['film_id']);

?>
<form enctype="multipart/form-data" action="<?php echo $action; ?>" method="post">
<table align="center" >
<tr><td class="bold_it"><?php echo $TEXT['menu-btn26-title']; ?></td><td>
    <select name="obr_id">
    <?php
        $query10 = "SELECT * FROM `tbl_obraschenie` ORDER BY kachestvo ";
          $result10 = mysqli_query($dbcnx,$query10);
            if (!$result10) {puterror2($result2['skin'],$TEXT['error-tbl18']); require_once "utils/bottom_film.php"; exit();}
              while($result_obr = mysqli_fetch_array($result10))
                {
                 $chk_obr = "<option value=".$result_obr['obr_id'].">".$result_obr['kachestvo']."";
                 echo $chk_obr;
                }
    ?>
    </select></td></tr>
<tr><td></td><td><input class="button2" type="submit" value="<?php echo $button; ?>" />
<input type="hidden" name="film_id" value="<?php echo $_GET['film_id']; ?>" />
</td></tr>
</table>
</form>
<?php
  require_once "utils/bottom_film.php";
?>
